@@ -356,7 +356,7 @@ class OpenEuler():
 
     def get_openEuler_core_rpm_list(self,os_version,os_arch):
         rpm2src=self.get_openEuler_core_rpm2src(os_version,os_arch)
-        return rpm2src.keys()
+        return list(rpm2src.keys())
 
     def get_openEuler_core_rpm2src(self,os_version,os_arch):
         rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_Core.json"
